```
Usage: vcd gateway configure-default-gateway enable-dns-relay 
           [OPTIONS] <gateway name>

Options:
  --enable / -disable  enables/disables the dns relay
  -h, --help           Show this message and exit.

```
